Returns the provenance / version manifest of the normative gait datasets bundled with the package: dataset name, version, population, age range, walking-speed condition, subject count, kinematic variables, units, data source, license, and citation.
Returns the provenance / version manifest of the normative gait datasets bundled with the package: dataset name, version, population, age range, walking-speed condition, subject count, kinematic variables, units, data source, license, and citation.